==> OI-Projet-Nicolas.Thiery-1.1.tar.gz: OI-Projet-Nicolas.Thiery-1.1/Board.java <==
/**
 * a class for the board of a Queens game
 *
 * @version	$Id: Board.java,v 1.1 2002/11/05 12:14:02 nthiery Exp $
 * @author	Nicolas M. Thiry <nthiery@users.sourceforge.net>
**/

public class Board {

    /**
     * Constructor for a new 10 x 10 board
     *
     **/
    public Board() {
	throw new RuntimeException("Not Implemented");
    }
    
    /**
     * Constructor for a new size x size board
     *
     * @param size	a non negative integer	
     **/
    public Board(int size) {
	throw new RuntimeException("Not Implemented");
    }
    
    /**
     * Saves the board in a file
     *
     * @param filename  a string: the name of the file
     * @throws	java.io.IOException if there is a problem reading the file
     **/
    public void save(String filename) {
	throw new RuntimeException("Not Implemented");
    }

    /**
     * Reads the board from a file
     *
     * @param filename  a string: the name of the file
     * @throws java.io.IOException if there is a problem writing in the file
     **/
    public void read(String filename) {
	throw new RuntimeException("Not Implemented");
    }

    /**
     * Prints the board on the screen
     *
     **/
    public void print() {
	throw new RuntimeException("Not Implemented");
    }

    
    /**
     * Returns the size of the board
     *
     * @return an integer: the size of the board
     **/
    public int size() {
	throw new RuntimeException("Not Implemented");
    }

    /**
     * Returns the content of a cell at a given position
     *
     * @param x,y  positive integers less or equal to size
     * @throws     out of bound exception
     * @return	   0  if the cell at position (x,y) is empty
     *		   2  if the cell at position (x,y) contains a white queen
     *		   1  if the cell at position (x,y) contains a white pawn
     *		   -1 if the cell at position (x,y) contains a black pawn
     *		   -2 if the cell at position (x,y) contains a black queen
     **/
    public int get(int x, int y) {
	throw new RuntimeException("Not Implemented");
    }

    /**
     * Returns the number of pawns of a given color on the board
     *
     * @param color	an integer: 1 for white, -1 for black
     * @return		a non-negative integer
     **/
    public int nbPawns() {
	throw new RuntimeException("Not Implemented");
    }

    /**
     * Returns the number of queens of a given color on the board
     *
     * @param color	an integer: 1 for white, -1 for black
     * @return		a non-negative integer
     **/
    public int nbQueens() {
	throw new RuntimeException("Not Implemented");
    }

    /**
     * Returns the number of pieces of a given color on the board
     *
     * @param color	an integer: 1 for white, -1 for black
     * @return		a non-negative integer
     **/
    public int nbPieces() {
	throw new RuntimeException("Not Implemented");
    }

    /**
     * Returns the number of moves done so far
     *
     * @return an integer
     **/
    public int nbMoves() {
	throw new RuntimeException("Not Implemented");
    }

    /**
     * Returns which color is next to play
     *
     * @return an integer: 1 for white, -1 for black
     **/
    public int nextPlayer() {
	throw new RuntimeException("Not Implemented");
    }

    /**
     * Returns whether the game is finished
     *
     * @return a boolean
     **/
    public boolean isFinished() {
	throw new RuntimeException("Not Implemented");
    }

    /**
     * Returns the winner of the game
     *
     * @return	   0  if the game is not finished or if the game is a draw
     *		   1  if the white wins
     *		   -1 if the black wins
     **/
    public int winner() {
	throw new RuntimeException("Not Implemented");
    }

    /**
     * Returns whether a move is legal
     *
     * @param move	a move of class Move
     * @return a boolean
     **/
    public boolean isLegal(Move move) {
	throw new RuntimeException("Not Implemented");
    }

    /**
     * Moves a piece on the board
     *
     * @param move	a move of class Move
     * @throws	IllegalMoveException if the move is illegal
     **/
    public void move(Move move) {
	throw new RuntimeException("Not Implemented");
    }
}

==> OI-Projet-Nicolas.Thiery-1.2.tar.gz: OI-Projet-Nicolas.Thiery-1.2/Board.java <==
/**
 * a class for the board of a Queens game
 *
 * @version	$Id: Board.java,v 1.5 2003/02/19 15:48:57 nthiery Exp $
 * @author	Nicolas M. Thiry <nthiery@users.sourceforge.net>
**/

public class Board {

    /**
     * Constructor for a new 10 x 10 board
     *
     **/
    public Board() {
	throw new RuntimeException("Not Implemented");
    }

    /**
     * Constructor for a new size x size board
     *
     * @param size	a non negative integer
     **/
    public Board(int size) {
	throw new RuntimeException("Not Implemented");
    }

    /**
     * Returns a string object representing this object
     *
     * @return	a string
     **/
    public String toString() {
	throw new RuntimeException("Not Implemented");
    }

    /**
     * Write the board on a stream
     *
     * @param o	an output stream
     * @throws	java.io.IOException if there is a problem writing to the stream
     **/
    public void write(OutputStream o) {
	// This will typically use the toString method
	throw new RuntimeException("Not Implemented");
    }

    /**
     * Saves the board in a file
     *
     * @param filename  a string: the name of the file
     * @throws	java.io.IOException if there is a problem writing to the file
     **/
    public void write(String filename) {
	// This will typically use the previous write method
	throw new RuntimeException("Not Implemented");
    }

    /**
     * Reads the board from a stream
     *
     * @param i	an input stream
     * @throws java.io.IOException if there is a problem reading from the stream
     **/
    public void read(InputStream i) {
	throw new RuntimeException("Not Implemented");
    }

    /**
     * Reads the board from a file
     *
     * @param filename  a string: the name of the file
     * @throws java.io.IOException if there is a problem reading from the file
     **/
    public void read(String filename) {
	// This will typically use the previous read method
	throw new RuntimeException("Not Implemented");
    }

    /**
     * Pretty prints the board on a stream
     *
     * @param o	an output stream
     **/
    public void print(OutputStream o) {
	throw new RuntimeException("Not Implemented");
    }

    /**
     * Pretty prints the board on the screen
     * (that is on the stream System.out)
     *
     **/
    public void print() {
	throw new RuntimeException("Not Implemented");
    }

    /**
     * Returns the size of the board
     *
     * @return an integer: the size of the board
     **/
    public int size() {
	throw new RuntimeException("Not Implemented");
    }

    /**
     * Returns the content of a cell at a given position
     *
     * @param x,y  positive integers less or equal to size
     * @throws     out of bound exception
     * @return	   0  if the cell at position (x,y) is empty
     *		   2  if the cell at position (x,y) contains a white queen
     *		   1  if the cell at position (x,y) contains a white pawn
     *		   -1 if the cell at position (x,y) contains a black pawn
     *		   -2 if the cell at position (x,y) contains a black queen
     **/
    public int get(int x, int y) {
	throw new RuntimeException("Not Implemented");
    }

    /**
     * Returns the number of pawns of a given color on the board
     *
     * @param color	an integer: 1 for white, -1 for black
     * @return		a non-negative integer
     **/
    public int nbPawns(int color) {
	throw new RuntimeException("Not Implemented");
    }

    /**
     * Returns the number of queens of a given color on the board
     *
     * @param color	an integer: 1 for white, -1 for black
     * @return		a non-negative integer
     **/
    public int nbQueens(int color) {
	throw new RuntimeException("Not Implemented");
    }

    /**
     * Returns the number of pieces of a given color on the board
     *
     * @param color	an integer: 1 for white, -1 for black
     * @return		a non-negative integer
     **/
    public int nbPieces(int color) {
	throw new RuntimeException("Not Implemented");
    }

    /**
     * Returns the number of moves done so far
     *
     * @return an integer
     **/
    public int nbMoves() {
	throw new RuntimeException("Not Implemented");
    }

    /**
     * Returns which color is next to play
     *
     * @return an integer: 1 for white, -1 for black
     **/
    public int nextPlayer() {
	throw new RuntimeException("Not Implemented");
    }

    /**
     * Returns whether the game is finished
     *
     * @return a boolean
     **/
    public boolean isFinished() {
	throw new RuntimeException("Not Implemented");
    }

    /**
     * Returns the winner of the game
     *
     * @return	   0  if the game is not finished or if the game is a draw
     *		   1  if the white wins
     *		   -1 if the black wins
     **/
    public int winner() {
	throw new RuntimeException("Not Implemented");
    }

    /**
     * Returns whether a move is legal
     *
     * @param move	a move of class Move
     * @return a boolean
     **/
    public boolean isLegal(Move move) {
	throw new RuntimeException("Not Implemented");
    }

    /**
     * Returns the list of legal moves for the next player
     *
     * @param
     * @return a linked list of legal moves
     **/
    public java.util.ArrayList legalMoves() {
	throw new RuntimeException("Not Implemented");
    }

    /**
     * Moves a piece on the board
     *
     * @param move	a move of class Move
     * @throws	IllegalMoveException if the move is illegal
     **/
    public void move(Move move) {
	throw new RuntimeException("Not Implemented");
    }
}
